@@ -1,13 +1,8 @@
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import print_function
-
 import json
 import logging
 import os.path
 import sys
 import warnings
-from builtins import range, str
 
 from .exceptions import (
     AuthenticationError,
@@ -31,8 +26,7 @@ logging.getLogger("urllib3.util.retry").setLevel(logging.DEBUG)
 
 warnings.filterwarnings("ignore", category=ImportWarning)
 # Disable `ResourceWarning` for python 3 due to unclosed request sessions
-if sys.version_info[0] >= 3:
-    warnings.filterwarnings("ignore", category=ResourceWarning)  # noqa
+warnings.filterwarnings("ignore", category=ResourceWarning)
 
 
 #: Default headers for all requests.
@@ -499,7 +493,7 @@ class SquirroClient(UserApiMixin, TopicApiMixin):
         if not hasattr(sys, "frozen"):
             # The `frozen` attribute is set in py2exe
             return None
-        exe_dir = os.path.dirname(str(sys.executable, sys.getfilesystemencoding()))
+        exe_dir = os.path.dirname(sys.executable, sys.getfilesystemencoding())
         ca_bundle = os.path.join(exe_dir, "cacert", "cacert.pem")
         if not os.path.exists(ca_bundle):
             return False
