@@ -5,7 +5,6 @@ import math
 import os
 import sys
 import time
-from builtins import object, range
 from configparser import SafeConfigParser
 from numbers import Number
 
@@ -190,7 +189,7 @@ class ItemUploader(object):
             # Otherwise fail
             # Warn ignoring fields if given
             if any([pipeline_workflow_id, pipeline_workflow_name, steps_config]):
-                log.warn(
+                log.warning(
                     "Ignoring parameters: `pipeline_workflow_id`, "
                     "`pipeline_workflow_name`, and `steps_config`"
                 )
@@ -203,7 +202,7 @@ class ItemUploader(object):
             # Otherwise fail
             # Warn ignoring fields if given
             if any([pipeline_workflow_name, steps_config]):
-                log.warn(
+                log.warning(
                     "Ignoring parameters: `pipeline_workflow_name`, "
                     "and `steps_config`"
                 )
