@@ -1,9 +1,7 @@
 # encoding: utf-8
-from __future__ import absolute_import, division, print_function, unicode_literals
 
 import json
 import sys
-from builtins import object
 
 from ..util import deprecation
 from .communities import CommunitiesMixin
@@ -11,7 +9,11 @@ from .community_subscription import CommunitySubscriptionsMixin
 from .community_types import CommunityTypesMixin
 from .contributingrecords import ContributingRecordsMixin
 from .dashboards import DashboardsMixin
+from .dss_candidate_set import DSSCandidateSet
 from .dss_groundtruth import DSSGroundTruthMixin
+from .dss_model import DSSModels
+from .dss_publish import DSSPublish
+from .dss_template import DSSTemplates
 from .email_templates import EmailTemplatesMixin
 from .enrichments import EnrichmentsMixin
 from .entities import EntitiesMixin
@@ -33,10 +35,6 @@ from .tasks import TasksMixin
 from .themes import ThemesMixin
 from .trenddetection import TrendDetectionMixin
 from .widgets_assets import WidgetsAndAssetsMixin
-from .dss_candidate_set import DSSCandidateSet
-from .dss_template import DSSTemplates
-from .dss_model import DSSModels
-from .dss_publish import DSSPublish
 
 MAX_UPDATE_COUNT = 10000  # ES hard limit is 10000
 MAX_UPDATE_SIZE = 80 * 1024 * 1024  # 80 MB (nginx has 96 MB limit)
@@ -503,7 +501,14 @@ class TopicApiBaseMixin(object):
         return self._process_response(res)
 
     def recommend_facets_explore(
-        self, project_id, method=None, count=10, data=None, start=None, next_params=None
+        self,
+        project_id,
+        method=None,
+        count=10,
+        data=None,
+        start=None,
+        next_params=None,
+        highlight=None,
     ):
         """Explore results of facet recommendation
 
@@ -538,6 +543,10 @@ class TopicApiBaseMixin(object):
         :param start: Zero based starting point.
         :param next_params: Parameter that were sent with the previous
             response as `next_params`.
+        :param highlight: Dictionary containing highlight information. Keys
+            are: `query` (boolean) if True the response will contain highlight
+            information. `smartfilters` (list): List of Smart Filter names to
+            be highlighted.
 
         :return: List of items with facets satisfied input
 
@@ -597,6 +606,7 @@ class TopicApiBaseMixin(object):
                     aggregations=aggregations,
                     start=start,
                     next_params=next_params,
+                    highlight=highlight,
                 )
                 res["aggregations"] = {
                     key: {
@@ -882,7 +892,14 @@ class TopicApiBaseMixin(object):
         return self._process_response(res)
 
     def recommend_entities_explore(
-        self, project_id, method=None, count=10, data=None, start=None, next_params=None
+        self,
+        project_id,
+        method=None,
+        count=10,
+        data=None,
+        start=None,
+        next_params=None,
+        highlight=None,
     ):
         """Explore results of entity recommendation
 
@@ -912,7 +929,10 @@ class TopicApiBaseMixin(object):
         :param start: Zero based starting point.
         :param next_params: Parameter that were sent with the previous
             response as `next_params`.
-
+        :param highlight: Dictionary containing highlight information. Keys
+            are: `query` (boolean) if True the response will contain highlight
+            information. `smartfilters` (list): List of Smart Filter names to
+            be highlighted.
         :return: List of items and entities satisfied input
 
         Example::
@@ -971,6 +991,7 @@ class TopicApiBaseMixin(object):
                     child_count=count,
                     start=start,
                     next_params=next_params,
+                    highlight=highlight,
                 )
                 agg_res = self.query_entities(
                     project_id=project_id,
