@@ -1,8 +1,5 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 import json
 import logging
-from builtins import object
 
 from squirro_client.util import deprecation
 
