@@ -1,9 +1,3 @@
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import unicode_literals
-from __future__ import print_function
-
-
 import base64
 import io
 import json
@@ -11,7 +5,6 @@ import logging
 import re
 import tarfile
 import time
-from builtins import object
 
 log = logging.getLogger(__name__)
 
