@@ -1,10 +1,7 @@
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 import base64
 import json
 import logging
 import re
-from builtins import object
 
 log = logging.getLogger(__name__)
 
@@ -231,8 +228,8 @@ class ProjectsMixin(object):
         :param import_items: Boolean. Whether to include the items,
             defaults to `True`. Needs the `import_facets` to be set to `True`
             also.
-        :param import_guide_file: Boolean. Whether to include the project guide file,
-            defaults to `True`.
+        :param import_guide_file: Boolean. Whether to include the project
+            project guide file, defaults to `True`.
         :returns: A dictionary which contains the project identifier.
 
         Example::
@@ -429,6 +426,7 @@ class ProjectsMixin(object):
         export_sources=True,
         export_sources_dataloader_plugins=True,
         export_trends=True,
+        export_guide_file=True,
         export_items=False,
         export_items_config=None,
     ):
@@ -514,12 +512,13 @@ class ProjectsMixin(object):
             the dataloaders, defaults to `True`.
         :param export_trends: Boolean. Whether to include the trends,
             defaults to `True`.
+        :param export_guide_file: Boolean. Whether to include the guide file,
+            defaults to `True`.
         :param export_items: Boolean. Whether to include the items,
             defaults to `False`. Needs the `export_facets` to be True.
         :param export_items_config: Dict. Containing the query parameters that
             can be used to filter down the exported items. Currently only
             `query` and `count` parameters are supported.
-
         Example::
 
             >>> res = client.export_project(
@@ -559,6 +558,7 @@ class ProjectsMixin(object):
             "export_sources": export_sources,
             "export_sources_dataloader_plugins": export_sources_dataloader_plugins,
             "export_trends": export_trends,
+            "export_guide_file": export_guide_file,
             "export_items": export_items,
             "export_synonyms": export_synonyms,
             "export_items_config": export_items_config,
