@@ -1,11 +1,7 @@
 # -*- coding: utf-8 -*-
-from __future__ import division
-from __future__ import absolute_import
-from __future__ import print_function
 
 import json
 import re
-from builtins import object
 
 
 class UserApiMixin(object):
@@ -357,7 +353,7 @@ class UserApiMixin(object):
     def add_user(self, email=None, password=None, role=None):
         """
         Add a new user to the current tenant.
-        
+
         :param email: Email address of the user.
         :param password: Password of the user.
         :param role: role of the user in the tenant. Must be one of:
